American Society for Indexing

### Navigation

## Home

The Voice of Excellence in Indexing

We advocate, educate, and provide the central resource for indexing.

## Webinars
ASI Webinar Replay: Making the Most of Macrex
with Do Mi Stauber

It’s time to go deeper and learn some of the many powerful functions of Macrex, functions that will enable you to work faster, increase your accuracy and the quality of your indexing, and produce any output that your clients prefer. Did you know that Macrex enables you to: never type the same thing twice? automate […]

## News
Hines Award—Call for Nominations for 2016

Nominations Due February 28, 2016 The Hines Award, named for Theodore Hines, was established to honor those who have provided exceptional service to the American Society for Indexing (ASI). Past winners of the Hines Award have been instrumental in writing and editing books, publicizing ASI program and services, forming and supporting chapters or SIGs (or […]

## Conference
2016 Indexing Conference Call for Presentation Proposals

Joint 2016 ASI-ISC/SCI Annual Conference Chicago, Illinois, United States June 15–18, 2016 Save the Date/Call for Papers The Indexing Conference for 2016 will be an international event! The Indexing Society of Canada/Société canadienne d’indexation (ISC/SCI) and the American Society for Indexing (ASI) have had a number of successful collaborations in the past (Montreal, Toronto, Vancouver) […]

## Online Learning
ASI Online Learning: Embedded Indexing in InDesign

Embedded Indexing in InDesign Three-Part Series with Lucie Haskins Step-by-step instruction on how to index in Adobe’s most popular desktop publishing program and–exclusive to this course–how to use the helpful KPS plugins. This three-part series exemplifies ASI’s commitment to ongoing training for indexers wanting to learn more, in the comfort of their own homes (or […]

## ASI Online Learning: Practical Taxonomy Creation

Practical Taxonomy Creation Three-Part Series with Heather Hedden “Practical Taxonomy Creation” is a 3-part ASI Online Learning course, taught by Heather Hedden. This is a terrific offering for indexers wanting to expand their skill set and create a wider vista for work. Where are taxonomies and controlled vocabularies needed? Periodical and database indexing and large, […]

## Organizational Members

See our list of organizational members.

## Affiliated Organizations